﻿using Dora.DynamicProxy;
using Microsoft.Extensions.Caching.Memory;
using Microsoft.Extensions.Options;
using System.Threading.Tasks;

namespace Spider.Core.Caching
{
    public class CacheInterceptor
    {
        private readonly IMemoryCache _cache;
        private readonly MemoryCacheEntryOptions _options;
        public CacheInterceptor(IMemoryCache cache, IOptions<MemoryCacheEntryOptions> optionsAccessor)
        {
            _cache = cache;
            _options = optionsAccessor.Value;
        }

        public async Task InvokeAsync(InvocationContext context)
        {
            var key = new CacheKey(context.Method, context.Arguments);
            if (_cache.TryGetValue(key, out var value))
            {
                context.ReturnValue = value;
            }
            else
            {
                await context.ProceedAsync();
                _cache.Set(key, context.ReturnValue, _options);
            }
        }
    }
}
