﻿using System;
using NPoco;

namespace Spider.Infrastructure.Pos
{
    /// <summary>
    /// 问题表
    /// </summary>
    /// <remarks>
    /// 问答模块，发布问题。
    /// 1. 所有已登录的用户都能对所见商品进行提问，并且可以匿名提问。
    /// 2. 提问需要等待后台管理员先进行审核，审核日期为7天，审核通过或到期后才能展示到商品问答列表。
    /// 3. 问题审核通过后，提问者不能删除、修改。
    /// 4. 一个问题，可以有多个回答。
    /// 5. 同一个商品可以被同一个提问者多次提问，但是内容不能相同。
    /// 6. 可以举报别人发布的问题。
    /// 7. 支持通过排序号手工干预排序。
    /// </remarks>
    [TableName(Constants.Tables.Questions)]
    [PrimaryKey("Id", AutoIncrement = true)]
    public class Question : ModelBase
    {
        /// <summary>
        /// 提问者标识
        /// </summary>
        public int QuestionerId { get; set; }
        /// <summary>
        /// 提问者名称
        /// </summary>
        public string QuestionerName { get; set; }
        /// <summary>
        /// 提问者头像
        /// </summary>
        public string QuestionerAvatar { get; set; }
        /// <summary>
        /// 商品标识
        /// </summary>
        public int ProductionId { get; set; }
        /// <summary>
        /// 商品名称
        /// </summary>
        public string ProductionName { get; set; }
        /// <summary>
        /// 商品缩略图
        /// </summary>
        public string ProductionThumbnail { get; set; }
        /// <summary>
        /// 已审核
        /// </summary>
        public bool IsAudited { get; set; } = false;
        /// <summary>
        /// 审核时间
        /// </summary>
        public DateTime? AuditTime { get; set; }

        /// <summary>
        /// 排序号
        /// </summary>
        public int? Order { get; set; }
        /// <summary>
        /// 回答数
        /// </summary>
        public int AnswerCount { get; set; }

        public override string ToString()
        {
            return $"[QuestionerId: {QuestionerId},QuestionerName: {QuestionerName},QuestionerAvatar: {QuestionerAvatar},ProductionId: {ProductionId},ProductionName: {ProductionName},ProductionThumbnail: {ProductionThumbnail},IsAudited: {IsAudited},AuditTime: {AuditTime},Order: {Order},AnswerCount: {AnswerCount},{base.ToString()}]";
        }
    }
}
